<h1 align="center">
    <strong>fastapi-hypothesis</strong>
</h1>
<p align="center">
    <a href="https://github.com/Kludex/fastapi-hypothesis" target="_blank">
        <img src="https://img.shields.io/github/last-commit/Kludex/fastapi-hypothesis" alt="Latest Commit">
    </a>
        <img src="https://img.shields.io/github/workflow/status/Kludex/fastapi-hypothesis/Test">
        <img src="https://img.shields.io/codecov/c/github/Kludex/fastapi-hypothesis">
    <br />
    <a href="https://pypi.org/project/fastapi-hypothesis" target="_blank">
        <img src="https://img.shields.io/pypi/v/fastapi-hypothesis" alt="Package version">
    </a>
    <img src="https://img.shields.io/pypi/pyversions/fastapi-hypothesis">
    <img src="https://img.shields.io/github/license/Kludex/fastapi-hypothesis">
</p>


## Installation

``` bash
pip install fastapi-hypothesis
```

## License

This project is licensed under the terms of the MIT license.
